Learn R Programming

extracat (version 1.7-3)

extracat: Categorical Data Analysis and Visualization

Description

This package offers a variety of functions that can be used for categorical data analysis or at least have to do with categorical data.

Among the most interesting features are ll{ rmb RMB plots visualize contingency tables. The function offers different visualizations of conditional distributions and their corresponding weights (frequencies) including multiple barcharts, spineplots and piecharts. There are different ways of displaying the residuals from statistical models. scpcp A static version of CPCP plots with labeling and color options. optile The OPTILE interface was developed for the Google Summer of Code 2011. It offers a variety of reordering techniques for contingency tables. The reordering of the categories not only improves visualizations. rmbmat A matrix of RMB plots not unlike a Scatterplot matrix (SPLOM) is produced. It uses binning for continuous data. hexpie After a hexagonal binning of x and y a third categorical target variable is displayed via piecharts (or embedded hexagons) within the hexagons. This avoids problems with overplotting. quickfechner A very fast implementation of the fechnerian scaling technique, which computes a fechnerian distance matrix from a (dis.)similarity matrix. The technique is equivalent to a shortest path algorithm. fluctile Offers two- or multidimensional fluctuation diagrams and multiple barcharts. arsim Simulates categorical data arrays of any dimension. The number of observations, the number of block clusters and the noise level and type can be chosen. }

Arguments

Details

ll{ Package: extracat Type: Package Version: 1.6-4 Date: 2013-12-11 License: - LazyLoad: yes }

References

Alexander Pilhoefer, Antony Unwin (2013). New Approaches in Visualization of Categorical Data: R Package extracat. Journal of Statistical Software, 53(7), 1-25. URL http://www.jstatsoft.org/v53/i07/